@@ -10,7 +10,7 @@ from yarl import URL
 
 from .exceptions import NotFoundError, TractiveError, UnauthorizedError
 
-CLIENT_ID = "5728aa1fc9077f7c32000186"
+CLIENT_ID = "625e533dc3c3b41c28a669f0"
 
 
 class API:  # pylint: disable=too-many-instance-attributes
@@ -39,7 +39,7 @@ class API:  # pylint: disable=too-many-instance-attributes
 
         if self.session is None:
             loop = loop or asyncio.get_event_loop()
-            self.session = aiohttp.ClientSession(loop=loop)
+            self.session = aiohttp.ClientSession()
             self._close_session = True
 
         self._user_credentials = None
